Skip to contents

An internal function to determine the version of SCCS used to store results

Usage

.getSccsVersion(connectionHandler, schema, sccsTablePrefix = "sccs_")

Arguments

connectionHandler

A connection handler that connects to the database and extracts sql queries. Create a connection handler via `ResultModelManager::ConnectionHandler$new()`.

schema

The result database schema (e.g., 'main' for sqlite)

sccsTablePrefix

The prefix used for the cohort generator results tables

Value

A integer with the major version number of cohort method

Details

Specify the connectionHandler, the schema and the prefixes. This query will attempt to identify if SelfControlledCaseSeries v6.1.4 was used by inspecing the migration table. When the migration_order is >= 3 then v6.1.4 of SelfControlledCaseSeries was used.