Skip to contents

A function to extract the case settings found in characterization

Usage

getCharacterizationCaseSettings(
  connectionHandler,
  schema,
  cTablePrefix = "c_",
  cgTablePrefix = "cg_",
  characterizationTargetIds = NULL,
  targetIds = NULL,
  outcomeIds = NULL
)

Arguments

connectionHandler

A connection handler that connects to the database and extracts sql queries. Create a connection handler via `ResultModelManager::ConnectionHandler$new()`.

schema

The result database schema (e.g., 'main' for sqlite)

cTablePrefix

The prefix used for the characterization results tables

cgTablePrefix

The prefix used for the cohort generator results tables

characterizationTargetIds

optional vector of characterizationTargetIds to restrict to

targetIds

optional vector of targetIds to restrict to

outcomeIds

optional vector of outcomeIds to restrict to

Value

A data.frame with the characterization target cohort ids, names and inclusion criteria.

Details

Specify the connectionHandler, the schema and the prefixes

Examples

conDet <- getExampleConnectionDetails()

connectionHandler <- ResultModelManager::ConnectionHandler$new(conDet)
#> Connecting using SQLite driver

caseCohorts <- getCharacterizationCaseSettings(
  connectionHandler = connectionHandler, 
  schema = 'main'
)