A function to extract case series continuous feature characterization results
Source:R/CharacterzationQueries.R
getContinuousCaseSeries.RdA function to extract case series continuous feature characterization results
Usage
getContinuousCaseSeries(
connectionHandler,
schema,
cTablePrefix = "c_",
cgTablePrefix = "cg_",
databaseTable = "database_meta_data",
characterizationTargetId = NULL,
characterizationCaseId = NULL,
outcomeId = NULL,
databaseIds = NULL,
riskWindowStart = NULL,
riskWindowEnd = NULL,
startAnchor = NULL,
endAnchor = NULL,
outcomeWashout = NULL
)Arguments
- connectionHandler
A connection handler that connects to the database and extracts sql queries. Create a connection handler via `ResultModelManager::ConnectionHandler$new()`.
- schema
The result database schema (e.g., 'main' for sqlite)
- cTablePrefix
The prefix used for the characterization results tables
- cgTablePrefix
The prefix used for the cohort generator results tables
- databaseTable
The name of the table with the database details (default 'database_meta_data')
- characterizationTargetId
The characterization target id to restrict results to
- characterizationCaseId
The characterization case id to restrict results to
- outcomeId
Am integer corresponding to the outcome cohort ID
- databaseIds
(optional) One or more unique identifiers for the databases
- riskWindowStart
(optional) A riskWindowStart to restrict to
- riskWindowEnd
(optional) A riskWindowEnd to restrict to
- startAnchor
(optional) A startAnchor to restrict to
- endAnchor
(optional) An endAnchor to restrict to
- outcomeWashout
(optional) the outcomeWashout to restrict to
See also
Other Characterization:
characterizationCompareBinary(),
characterizationCompareContinuous(),
getBinaryCaseSeries(),
getBinaryRiskFactors(),
getBinaryTargetBaseline(),
getCaseCounts(),
getCharacterizationCaseSettings(),
getCharacterizationDemographics(),
getCharacterizationTargetSettings(),
getContinuousRiskFactors(),
getContinuousTargetBaseline(),
getDechallengeRechallenge(),
getDechallengeRechallengeFails(),
getIncidenceRates(),
getIncidenceTargetSettings(),
getNonCaseCounts(),
getOutcomesUsedInCharacterization(),
getOutcomesUsedInIncidence(),
getTargetCounts(),
getTargetsUsedInCharacterization(),
getTargetsUsedInIncidence(),
getTimeToEvent(),
plotAgeDistributions(),
plotSexDistributions(),
viewIncidenceRate()
Examples
conDet <- getExampleConnectionDetails()
connectionHandler <- ResultModelManager::ConnectionHandler$new(conDet)
#> Connecting using SQLite driver
cs <- getContinuousCaseSeries(
connectionHandler = connectionHandler,
schema = 'main',
characterizationTargetId = 1,
outcomeId = 3
)