Skip to contents

A function to extarct the cohort incidence targets

Usage

getIncidenceTargetSettings(
  connectionHandler,
  schema,
  ciTablePrefix = "ci_",
  cgTablePrefix = "cg_",
  targetIds = NULL
)

Arguments

connectionHandler

A connection handler that connects to the database and extracts sql queries. Create a connection handler via `ResultModelManager::ConnectionHandler$new()`.

schema

The result database schema (e.g., 'main' for sqlite)

ciTablePrefix

The prefix used for the cohort incidence results tables

cgTablePrefix

The prefix used for the cohort generator results tables

targetIds

optional vector of targetIds to restrict to

Value

A data.frame with the characterization target cohort ids, names and inclusion criteria.

Details

Specify the connectionHandler, the schema and the prefixes

Examples

conDet <- getExampleConnectionDetails()

connectionHandler <- ResultModelManager::ConnectionHandler$new(conDet)
#> Connecting using SQLite driver

targetCohorts <- getIncidenceTargetSettings(
  connectionHandler = connectionHandler, 
  schema = 'main'
)