A function to extract the outcomes found in incidence
Source:R/CharacterzationQueries.R
getOutcomesUsedInIncidence.RdA function to extract the outcomes found in incidence
Usage
getOutcomesUsedInIncidence(
connectionHandler,
schema,
ciTablePrefix = "ci_",
cgTablePrefix = "cg_",
targetId = NULL,
parentId = NULL
)Arguments
- connectionHandler
A connection handler that connects to the database and extracts sql queries. Create a connection handler via `ResultModelManager::ConnectionHandler$new()`.
- schema
The result database schema (e.g., 'main' for sqlite)
- ciTablePrefix
The prefix used for the cohort incidence results tables
- cgTablePrefix
The prefix used for the cohort generator results tables
- targetId
An integer corresponding to the target cohort ID
- parentId
the parent target cohort Id to extract outcomes for
See also
Other Characterization:
characterizationCompareBinary(),
characterizationCompareContinuous(),
getBinaryCaseSeries(),
getBinaryRiskFactors(),
getBinaryTargetBaseline(),
getCaseCounts(),
getCharacterizationCaseSettings(),
getCharacterizationDemographics(),
getCharacterizationTargetSettings(),
getContinuousCaseSeries(),
getContinuousRiskFactors(),
getContinuousTargetBaseline(),
getDechallengeRechallenge(),
getDechallengeRechallengeFails(),
getIncidenceRates(),
getIncidenceTargetSettings(),
getNonCaseCounts(),
getOutcomesUsedInCharacterization(),
getTargetCounts(),
getTargetsUsedInCharacterization(),
getTargetsUsedInIncidence(),
getTimeToEvent(),
plotAgeDistributions(),
plotSexDistributions(),
viewIncidenceRate()
Examples
conDet <- getExampleConnectionDetails()
connectionHandler <- ResultModelManager::ConnectionHandler$new(conDet)
#> Connecting using SQLite driver
outcomes <- getOutcomesUsedInIncidence(
connectionHandler = connectionHandler,
schema = 'main'
)