Skip to contents

Function that converts a subsetDefinitionJson into text description

Usage

getSubsetText(subsetDefinitionJson, cohortDefinitions)

Arguments

subsetDefinitionJson

The subset logic json

cohortDefinitions

A data.frame with the columns cohortDefinitionId, cohortName and optionally friendlyName that will be used to know the friendly cohort name for any subsetting that nests in other cohorts

Value

A text string describing the subsetting

Details

The function takes a subsetDefinitionJson and converts it into friendly text describing the subset logic