A function to extract the targets found in incidence
Source:R/CharacterzationQueries.R
getTargetsUsedInIncidence.RdA function to extract the targets found in incidence
Usage
getTargetsUsedInIncidence(
connectionHandler,
schema,
ciTablePrefix = "ci_",
cgTablePrefix = "cg_"
)Arguments
- connectionHandler
A connection handler that connects to the database and extracts sql queries. Create a connection handler via `ResultModelManager::ConnectionHandler$new()`.
- schema
The result database schema (e.g., 'main' for sqlite)
- ciTablePrefix
The prefix used for the cohort incidence results tables
- cgTablePrefix
The prefix used for the cohort generator results tables
See also
Other Characterization:
characterizationCompareBinary(),
characterizationCompareContinuous(),
getBinaryCaseSeries(),
getBinaryRiskFactors(),
getBinaryTargetBaseline(),
getCaseCounts(),
getCharacterizationCaseSettings(),
getCharacterizationDemographics(),
getCharacterizationTargetSettings(),
getContinuousCaseSeries(),
getContinuousRiskFactors(),
getContinuousTargetBaseline(),
getDechallengeRechallenge(),
getDechallengeRechallengeFails(),
getIncidenceRates(),
getIncidenceTargetSettings(),
getNonCaseCounts(),
getOutcomesUsedInCharacterization(),
getOutcomesUsedInIncidence(),
getTargetCounts(),
getTargetsUsedInCharacterization(),
getTimeToEvent(),
plotAgeDistributions(),
plotSexDistributions(),
viewIncidenceRate()
Examples
conDet <- getExampleConnectionDetails()
connectionHandler <- ResultModelManager::ConnectionHandler$new(conDet)
#> Connecting using SQLite driver
cohorts <- getTargetsUsedInIncidence(
connectionHandler = connectionHandler,
schema = 'main'
)