A function to add indexes to the Characterization results
Source:R/Indexes.R
createCharacterizationIndexes.RdA function to add indexes to the Characterization results
Arguments
- connectionHandler
A connection handler that connects to the database and extracts sql queries. Create a connection handler via `ResultModelManager::ConnectionHandler$new()`.
- schema
The result database schema (e.g., 'main' for sqlite)
- cTablePrefix
The prefix used for the characterization results tables
See also
Other Indexes:
createCohortIndexes(),
createIncidenceIndexes(),
createSccsIndexes()