A function to add indexes to the Cohort Generator results
Source:R/Indexes.R
createCohortIndexes.RdA function to add indexes to the Cohort Generator results
Arguments
- connectionHandler
A connection handler that connects to the database and extracts sql queries. Create a connection handler via `ResultModelManager::ConnectionHandler$new()`.
- schema
The result database schema (e.g., 'main' for sqlite)
- cgTablePrefix
The prefix used for the cohort generator results tables
See also
Other Indexes:
createCharacterizationIndexes(),
createIncidenceIndexes(),
createSccsIndexes()