An internal function to determine the version of CohortMethod used to store results
Source:R/EstimationQueries.R
dot-getCmVersion.RdAn internal function to determine the version of CohortMethod used to store results
Arguments
- connectionHandler
A connection handler that connects to the database and extracts sql queries. Create a connection handler via `ResultModelManager::ConnectionHandler$new()`.
- schema
The result database schema (e.g., 'main' for sqlite)
- cmTablePrefix
The prefix used for the cohort method results tables
Details
Specify the connectionHandler, the schema and the prefixes. This query will attempt to identify if CohortMethod v6 was used by inspecing the migration table. When the migration_order is >= 3 then v6 of CohortMethod was used.
See also
Other Estimation:
getCMEstimation(),
getCmDiagnosticsData(),
getCmMetaEstimation(),
getCmNegativeControlEstimates(),
getCmOutcomes(),
getCmPropensityModel(),
getCmTable(),
getCmTargets(),
getSccsDiagnosticsData(),
getSccsEstimation(),
getSccsMetaEstimation(),
getSccsModel(),
getSccsNegativeControlEstimates(),
getSccsOutcomes(),
getSccsTable(),
getSccsTargets(),
getSccsTimeToEvent(),
plotCmEstimates(),
plotSccsEstimates()