A function to extarct the cohort incidence targets
Source:R/CharacterzationQueries.R
getIncidenceTargetSettings.RdA function to extarct the cohort incidence targets
Usage
getIncidenceTargetSettings(
connectionHandler,
schema,
ciTablePrefix = "ci_",
cgTablePrefix = "cg_",
targetIds = NULL
)Arguments
- connectionHandler
A connection handler that connects to the database and extracts sql queries. Create a connection handler via `ResultModelManager::ConnectionHandler$new()`.
- schema
The result database schema (e.g., 'main' for sqlite)
- ciTablePrefix
The prefix used for the cohort incidence results tables
- cgTablePrefix
The prefix used for the cohort generator results tables
- targetIds
optional vector of targetIds to restrict to
See also
Other Characterization:
characterizationCompareBinary(),
characterizationCompareContinuous(),
getBinaryCaseSeries(),
getBinaryRiskFactors(),
getBinaryTargetBaseline(),
getCaseCounts(),
getCharacterizationCaseSettings(),
getCharacterizationDemographics(),
getCharacterizationTargetSettings(),
getContinuousCaseSeries(),
getContinuousRiskFactors(),
getContinuousTargetBaseline(),
getDechallengeRechallenge(),
getDechallengeRechallengeFails(),
getIncidenceRates(),
getNonCaseCounts(),
getOutcomesUsedInCharacterization(),
getOutcomesUsedInIncidence(),
getTargetCounts(),
getTargetsUsedInCharacterization(),
getTargetsUsedInIncidence(),
getTimeToEvent(),
plotAgeDistributions(),
plotSexDistributions(),
viewIncidenceRate()
Examples
conDet <- getExampleConnectionDetails()
connectionHandler <- ResultModelManager::ConnectionHandler$new(conDet)
#> Connecting using SQLite driver
targetCohorts <- getIncidenceTargetSettings(
connectionHandler = connectionHandler,
schema = 'main'
)