Creates a table with the incidence rates and optionally demographics
Usage
viewIncidenceRate(
incidenceData,
ageData = NULL,
genderData = NULL,
stratification = "overall",
maxAgeSampleSize = 5000
)Arguments
- incidenceData
The data extracted using 'getIncidenceRates'
- ageData
The data extracted using 'getBinaryTargetBaseline' with analysisIds = 3
- genderData
The data extracted using 'getBinaryTargetBaseline' with analysisIds = 1
- stratification
Pick either overall/age/sex/year to specify whether to view the overall rates or stratified by age/sex/year
- maxAgeSampleSize
When creating the age distributions this is the max age vector length to create
See also
Other Characterization:
getBinaryCaseSeries(),
getBinaryRiskFactors(),
getBinaryTargetBaseline(),
getCaseCounts(),
getCaseTargetCounts(),
getCharacterizationCohortBinary(),
getCharacterizationCohortContinuous(),
getCharacterizationDemographics(),
getCharacterizationOutcomes(),
getCharacterizationTargets(),
getContinuousCaseSeries(),
getContinuousRiskFactors(),
getDechallengeRechallenge(),
getDechallengeRechallengeFails(),
getIncidenceOutcomes(),
getIncidenceRates(),
getIncidenceTargets(),
getTargetBinaryFeatures(),
getTargetContinuousFeatures(),
getTimeToEvent(),
plotAgeDistributions(),
plotSexDistributions()
Examples
conDet <- getExampleConnectionDetails()
connectionHandler <- ResultModelManager::ConnectionHandler$new(conDet)
#> Connecting using SQLite driver
schema <- 'main'
incidenceData <- getIncidenceRates(
connectionHandler = connectionHandler ,
schema = schema
)
# incidence data does not have rate values to imputing them
incidenceData$incidenceRateP100py <- 1 +
sample(c(-1,1),replace = TRUE)*runif(nrow(incidenceData))
incidenceData$incidenceProportionP100p <- 0.5 +
sample(c(-1,1),replace = TRUE)*runif(nrow(incidenceData))
ageData <- getBinaryTargetBaseline(
connectionHandler = connectionHandler,
schema = schema,
analysisIds = 3
)
genderData <- getBinaryTargetBaseline(
connectionHandler = connectionHandler,
schema = schema,
analysisIds = 1
)
viewIncidenceRate(
incidenceData = incidenceData,
ageData = ageData,
genderData = genderData
)
#> Closing database connection
#> Closing database connection
Database
Rate per 100 person years
Proportion per 100 persons
N
Mean Follow-up Days
Outcomes
Age
Male %
- GI bleed ( wo 9999) during ( start + 0 ) - ( end + 0 )
- GI bleed ( wo 9999) during ( start + 0 ) - ( start + 365 )